==> generator-weblog-0.0.2.tgz: package/README.md <==
# generator-weblog

**This is very much an under-development project. You are more than welcome to use it and provide feedback, but in its current form, it is very limited in functionality.**

See how using the following tools helps you worry about... nothing!

[Yeoman](https://github.com/yeoman)
> Bootstrap your project with all the pieces necessary configured for you.

[Showdown](https://github.com/coreyti/showdown)
> Write your blog posts in your favorite style: Markdown!

[Showup](https://github.com/stephenplusplus/showup)
> Don't worry about style, fetching posts, or implementing search. Showup's got you!

[Grunt](gruntjs.com)
> While writing your posts, run `grunt server` to see your changes.
>
> Then, when you like what you see, just run a `grunt build` before committing to GitHub.

[GitHub](http://github.com)
> You already have a free account... now, it's your web host! Just push to the `gh-pages` branch of any of your repositories.

#### The results:
![](http://s16.postimg.org/58gu8rvhx/showup_preview.png)

#### Demo:
[Click here](http://stephenplusplus.github.io/generator-weblog) and type "angular" to pull up a post!

## Getting started
- Make sure you have [yo](https://github.com/yeoman/yo) installed:
    `npm install -g yo`
- Install the generator **locally**: `npm install generator-weblog`
- To get your blog going, run: `yo weblog`
- To create a post, run: `yo weblog:post`
- To bundle up your site before committing, run: `grunt build`

## License
[MIT License](http://en.wikipedia.org/wiki/MIT_License)

==> generator-weblog-0.0.3.tgz: package/README.md <==
# generator-weblog

**This is very much an under-development project. You are more than welcome to use it and provide feedback, but in its current form, it is very limited in functionality.**

See how using the following tools helps you worry about... nothing!

[Yeoman](https://github.com/yeoman)
> Bootstrap your project with all the pieces necessary configured for you.

[Showdown](https://github.com/coreyti/showdown)
> Write your blog posts in your favorite style: Markdown!

[Showup](https://github.com/stephenplusplus/showup)
> Don't worry about style, fetching posts, or implementing search. Showup's got you!

[Grunt](gruntjs.com)
> While writing your posts, run `grunt server` to see your changes.
>
> Then, when you like what you see, just run a `grunt build` before committing to GitHub.

[GitHub](http://github.com)
> You already have a free account... now, it's your web host! Just push to the `gh-pages` branch of any of your repositories.

#### The results:
[![Sample](http://s23.postimg.org/4wbfxk0ff/angular_showup_sample.png)](http://stephenplusplus.github.io/generator-weblog)

#### Demo:
[Click here](http://stephenplusplus.github.io/generator-weblog). Type "angular" to see the search in action.

## Getting started
- Make sure you have [yo](https://github.com/yeoman/yo) installed:
    `npm install -g yo`
- Install the generator **locally**: `npm install generator-weblog`
- To get your blog going, run: `yo weblog`
- To create a post, run: `yo weblog:post`
- To bundle up your site before committing, run: `grunt build`

## License
[MIT License](http://en.wikipedia.org/wiki/MIT_License)
